@@ -36,8 +36,11 @@ def get_kubernetes_structure_path(snapshot_source):
     get_kubernetes_structure_path will get kubernetes connector file path
     from configuration file.
     """
-    connector_path = '%s/%s/%s.json' % \
-                 (framework_dir(),config_value('KUBERNETES','kubernetsStructureFolder'),snapshot_source)
+    folder = config_value('KUBERNETES','kubernetesStructureFolder')
+    if folder:
+        connector_path = '%s/%s/%s.json' % (framework_dir(), folder, snapshot_source)
+    else:
+        connector_path = '%s/%s.json' % (framework_dir(), snapshot_source)
     return connector_path
 
 def get_kubernetes_structure_data(snapshot_source):
@@ -260,7 +263,7 @@ def node_db_record(snapshot,node):
     "structure":"kubernetes",
     "reference": snapshot['namespace'],
     "source": snapshot['source'],
-    "path":get_field_value(node,"paths")[0],
+    "paths": get_field_value(node,"paths"),
     "timestamp": int(time.time() * 1000),
     "queryuser": snapshot['serviceAccount'],
     "checksum":hashlib.md5("{}".encode('utf-8')).hexdigest(),
@@ -533,4 +536,4 @@ def populate_kubernetes_snapshot(snapshot, container=None):
                 logger.error('\t ERROR INFO : \n \tfile name : %s\n \tline : %s\n \ttype : %s\n \tobject : %s',fname,exc_tb.tb_lineno,exc_type,exc_obj)
                 print(traceback.format_exc())
                 raise ex
-    return snapshot_data
\ No newline at end of file
+    return snapshot_data
