@@ -30,14 +30,18 @@ def hcl_to_json(file_path):
     """
     json_data = {}
     try:
-        with open(file_path, 'r') as fp:
+        with open(file_path, 'r', encoding="utf-8") as fp:
             json_data = hcl2.load(fp)
             json_data = remove_list_from_values(json_data)
     except Exception:
         try:
-            with open(file_path, 'r') as fp:
+            with open(file_path, 'r', encoding="utf-8") as fp:
                 json_data = hcl.load(fp)
         except Exception as e:
             logger.error("Failed to convert hcl to json data, file: %s , error: %s", file_path, str(e))
 
-    return json_data
\ No newline at end of file
+    return json_data
+
+if __name__ == "__main__":
+    json_data = hcl_to_json("/home/swan-13/Desktop/vars.tf")
+    print(json_data)
\ No newline at end of file
